@@ -35,3 +35,10 @@ test_that("works with discrete response", {
   fit <- vinereg(y ~ ., dat, fam = "tll")
   expect_silent(cpit(fit, dat))
 })
+
+test_that("works on uscale", {
+  dat[] <- runif(nrow(dat) * ncol(dat))
+  fit <- vinereg(y ~ ., dat, uscale = TRUE)
+  p <- cpit(fit, dat)
+  expect_true(all(p >= 0 & p <= 1))
+})
